function [dLamb, dBeta] = aberrEcli(lamb, beta, ...
                                              lonSolV, excenT, lperiT)
% aberrEcli : Ecarts en coord. eclip. dus a l'aberration annuelle
% Usage : [dLamb, dBeta] = aberrEcli(lamb, beta, ...
%                                             lonSolV, excenT, lperiT);
% Entrees :
%   lamb, beta : longitude et latitude de l'etoile a corriger
% Entrees faculatives :
%   lonSolV : longitude vraie du Soleil
%   excenT  : eccentricity de l'orbite de la Terre a la date
%   lperiT  : longitude périhélie de l'orbite de la Terre 
% Sorties :
%   dAlpha, dDelta : variation a appliquer a lamb et beta.
%   TOUS LES ANGLES ENTREES ET SORTIES : EN RADIANS !!!!!!!!
global exenCou lonSolCou lperiTCou
if nargin < 3
   if isempty(exenCou), initAstro; endif
   lonSolV = lonSolCou;
   excenT = exenCou;
   lperiT = lperiTCou;
endif
    Kappa = 0.99364e-4;  % 20.4952 secondes de degrés convertis en radians
    lsml = lonSolV - lamb; clsml = cos(lsml); slsml = sin(lsml);
    pml = lperiT - lamb; cpml = cos(pml); spml = sin(pml);
    dLamb = Kappa*(-clsml + excenT*cpml)/cos(beta);
    dBeta = - Kappa*sin(beta)*(slsml - excenT*spml);
endfunction
