function [dAlpha, dDelta] = aberrEqua(ra, dec, obliq, ...
                                              lonSolV, excenT, lperiT)
% aberrEqua : Ecarts en coord. equat. dus a l'aberration annuelle
% Usage : [dAlpha, dDelta] = aberrEqua(ra, dec, obliq, ...
%                                              lonSolV, excenT, lperiT);
% Entrees :
%   ra, dec : ascension droite et declinaison de l'etoile a corriger
%   obliq   : obliquité vraie de l'écliptique
%   lonSolV : longitude vraie du Soleil
%   excenT  : eccentricity de l'orbite de la Terre a la date
%   lperiT  : longitude périhélie de l'orbite de la Terre 
% Sorties :
%   dAlpha, dDelta : variation a appliquer a ra et dec.
%   TOUS LES ANGLES ENTREES ET SORTIES : EN RADIANS !!!!!!!!
global epsCou exenCou lonSolCou lperiTCou
if nargin < 3
   if isempty(exenCou), initAstro; endif
   obliq = epsCou;
   lonSolV = lonSolCou;
   excenT = exenCou;
   lperiT = lperiTCou;
endif
    Kappa = 0.99364e-4;  % 20.4952 secondes de degrés convertis en radians
    cosa = cos(ra); sina = sin(ra);
    cosDec = cos(dec); sinDec = sin(dec);
    cosEps = cos(obliq); sinEps = sin(obliq);
    cosLE = cos(lonSolV); sinLE = sin(lonSolV);
    A = cosa*cosEps;
    C = sinEps*cosDec - cosEps*sina*sinDec;
    D = cosa*sinDec;
    dAlpha = -Kappa*(A*cosLE + sina*sinLE)/cos(dec);
    dDelta = -Kappa*(C*cosLE + D*sinLE);
    cosp = cos(lperiT); sinp = sin(lperiT);
    k = Kappa*excenT;
    dAlpha = dAlpha + k*(A*cosp + sina*sinp)/cos(dec);
    dDelta = dDelta + k*(C*cosp + D*sinp);
endfunction
