function [E] = anoM2anoE(M , e, methode, precision)
% anoM2anoE : Resolution de l'equation de Kepler par iterations
% Usage : E = anoM2anoE(M , e, methode, precision);
% Entrees : 
%   M         : Anomalie moyenne en radians
%   methode   : 1 simple, 2 newton (1 par défaut)
%   precision : arrêt iterations quand |dM| ou |dE| < precision
% Retour  : 
%   E         : Anomalie excentrique trouvee
% La methode 1 met en general une iteration de plus que la methode 2
% pour converger, mais comme elle est plus simple, elle peut etre
% plus rapide.
if nargin < 4, precision = eps; end
if nargin < 3, methode = 1; end

switch methode
	case 2 % methode 2 : newton
		E = M;
		for i = 1 : 10
			sE = sin(E);
			cE = cos(E);
			dM = M - (E - e * sE);
			if abs(dM) < precision, break; end
			umecE = 1. - e*cE;
			delta = umecE*umecE + 2*e*sE*dM;
			if delta > 0
				dE = (-umecE + sqrt(delta))/(e*sE);
			else
				dE = dM/umecE;
			end
			E = E + dE;
			if abs(dE) < precision, break; end
		end  %endfor
	otherwise % methode 1, iteration simple
		E = M;
		for i = 1 : 10
			dM = M - (E - e * sin(E));
			if abs(dM) < precision, break; end
			dE = dM  / (1. - e * cos(E) ) ;
			E = E + dE;
			if abs(dE) < precision, break; end      
		end %endfor  
end % endswitch
endfunction