function [v, iter] = anoM2anoV(M , e, methode, precision)
% anoM2anoV : Passage de l'anomalie moyenne a l'anomalie vraie.
% Usage : v = anoM2anoV(M , e, methode, precision);
% Entrees : 
%   M         : Anomalie moyenne en radians
%   methode   :
%               0 developpement limite
%               1 par resolution 1 de l'equation de Kepler (par defaut)
%               2 par resolution 2 de l'equation de Kepler
%   precision : arret quand |dM| ou |dE| < precision
% Retour  : 
%   E         : Anomalie excentrique trouvee
% La methode 1 met en general une iteration de plus que la methode 2
% pour converger, mais comme elle est plus simple, elle peut etre
% plus rapide.
switch methode
	case 0 % calcul direct par un developpement limite
      iter = 1;
      v = M + e*( (2 - e*e/4)*sin(M) + e*((5/4 - 11*e*e/24)*sin(2*M) + ...
              e*(13*sin(3*M)/12 + 103 * e *sin(4*M) / 96))) ;
	case {1, 2} 
    if nargin < 4, precision = eps; end
    if nargin < 3, methode = 1; end
    [E, iter] = anoM2anoE(M, e, methode, precision);
    cE = cos(E); sE = sin(E); umecE = 1. - e*cE;
    cv = (cE - e)/umecE;
    sv = sqrt(1-e*e)*sE/umecE;
    v = atan2(sv,cv);     
end % endswitch
endfunction