function [niter, jlev, azilev, jtra, htra, jpon, azipon] = astre_ju2ephem(ju, nom, longiA, latiA)
% astre_ju2ephem : date julienne UT des lever, transit et coucher d'un astre
niter = 0;
jtra = -1; jlev = -1; jpon = -1;
azipon = 0.; azilev = 0.;
%% Traitement lieu d'observation
global longiCou latiCou
if nargin < 4,
  if isempty(latiCou), initAstro; endif
  latiA = latiCou; 
endif
if nargin < 3, longiA = longiCou; endif
%% Traitement nom de l'astre
name = tolower(nom);
num = -1;
star = "";
switch name
 case {"mercure", "mercury"}, num = 1;
 case {"vénus", "venus"},     num = 2;
 case {"sun", "soleil"},      num = 3;
 case {"mars"},               num = 4;
 case {"jupiter"},            num = 5;
 case {"saturne","saturn"},   num = 6;
 case {"uranus"},             num = 7;
 case {"neptune", "neptun"},  num = 8;
 case { "moon", "lune"},      num = 9; 
 otherwise
  star = star_find (nom)
  if ~isempty(star),          num = 10; endif
endswitch
if num < 0, disp("Astre non reconnue :"); return; endif
%% Hauteur de l'astre au début de sa visibilité
%% et instant proche du transit
if num == 3 % Soleil
  h0 = -0.8333*pi/180; % rayon angulaire soleil + refraction
  jref = floor(ju + 0.5); % midi local de ce jour  
elseif num == 9 % Lune
  h0 = 0.125*pi/180.; % approximation pour la Lune
  jref = ju;
else % planete ou etoile
  h0 = -0.5667*pi/180.; %Refraction au niveau de l'horizon
  jref = floor(ju + 0.5) +0.5; % minuit local de ce jour
endif
jref -=  longiA/(2.*pi); % date UT pour date locale
sinh0 = sin(h0);
sinPhiA = sin(latiA); cosPhiA = cos(latiA);
%% Constantes ou données initiales
omegaT = (360.98564736629/360.)*2*pi; % vrot_terre rd/jours
epstest = 0.1/86400; % Arret des itérations a 0.1 s près.
DeltaT = jul2deltaT(jref);
% Ascension droite méridien local à jref
Aref = jul2agst_rd(jref) + longiA;
% Postion de l'astre à jref UT
[raSref dec] = jeAstre2equa(jref + DeltaT, num, star);
% Hauteur de l'astre au passage au méridien
htra = pi/2 - abs(latiA - dec);
deltaAsc = realmod2(raSref - Aref, 2*pi);
jtra = jref + deltaAsc/omegaT;
if  htra < h0
disp('Etoile sous horizon ! : h < h0');
return; endif % pas de solution
cosH = (sinh0 - sinPhiA*sin(dec))/(cosPhiA*cos(dec));
if abs(cosH) > 1
 disp('Etoile sous horizon ! : abs(cosH) > 1'); 
 return; endif % pas de solution
H = acos(cosH);
jlev = jref + (deltaAsc - H)/omegaT;
jpon = jref + (deltaAsc + H)/omegaT;
for niter = 1:10
  jtra_old = jtra; 
  jlev_old = jlev;  
  jpon_old = jpon;  
  [raSref dec] = jeAstre2equa(jtra + DeltaT, num, star);
  sinDec = sin(dec);
  jtra = jref + realmod2(raSref - Aref, 2*pi)/omegaT;
  % Postion de l'astre au lever
  [raSlev dec] = jeAstre2equa(jlev + DeltaT, num, star); 
  cosHlev = (sinh0 - sinPhiA*sinDec)/(cosPhiA*cos(dec));
  if abs(cosHlev) > 1, 
    jlev = -1; jpon = -1;
    return; 
  endif
  hLev = -acos(cosHlev);
  jlev = jref + (realmod2(raSlev - Aref, 2*pi) + hLev)/omegaT;
  % Postion de l'astre au coucher
  [raScou dec] = jeAstre2equa(jpon + DeltaT, num, star);
  cosHcou = (sinh0 - sinPhiA*sinDec)/(cosPhiA*cos(dec));
   if abs(cosHcou) > 1, 
    jlev = -1; jpon = -1;
    return; 
  endif
  hCou = acos(cosHcou); 
  jpon = jref + (realmod2(raScou - Aref, 2*pi) + hCou)/omegaT;
  if (jlev_old-jlev) < epstest && (jpon_old-jpon) < epstest ...
                                   && (jtra_old-jtra) < epstest
    break;
  endif
endfor
cosDec = cos(dec);
% cosh0 = cos(h0);
% azilev = -acos((sinPhiA*cosHlev*cosDec-cosPhiA*sinDec)/ cosh0);
% azipon =  acos((sinPhiA*cosHcou*cosDec-cosPhiA*sinDec)/ cosh0);
azilev = atan2(sin(hLev), sinPhiA*cosHlev - cosPhiA*sinDec/cosDec);
azipon = atan2(sin(hCou), sinPhiA*cosHcou - cosPhiA*sinDec/cosDec);
endfunction

%%
%% Calcul des coordonnées equatoriales de l'astre
%%
function [ra de] = jeAstre2equa(je, num, star)
if num < 9 % cas planete ou soleil
  [ra, de, rho] = planet_je2equa(je, num, false, true);
elseif num == 9 % cas Lune
  [ra, de, distTL]  = moon_je2equa(je, false);
else % num = 10, cas etoile
  [ra, de] = star_je2equa (je, star, false);
endif
endfunction

