function [lambda beta] = chDateCoorEcli(lambda0, beta0, JD0, JD)
% chDateCoorEcli : Changement de date de coordonnees ecliptiques
% Usage : [lambda beta] = chDateCoorEcli(lambda0, beta0, JD0, JD);
% Entrees : 
%   lambda0, beta0 : coord. ecli. a l'epoque initiale en RADIANS
%   JD0 : jour julien dela premiere date (celle des coordonnees lambda0, beta0) 
%   JJ  : jour julien de la date finale (celle des coordonnees a calculer)
% Sorties :
%   lambda, beta : Coordonnees a la date finale, en RADIANS.
	T = (JD0 - 2451545.0)/36525;	% Siecle julien initial par rapport a J2000
	d = (JD-JD0)/36525;   % écart en siecles juliens	
	a = 47.0029 + T*(-0.06603 + 0.000598*T);
	b = -0.03302+0.000598*T;
	eta = d*(a+d*(b+d*0.00006)); % en secondes angulaires
	eta = (eta/3600)*pi/180.;    % en radians
	a = 174.876384*3600 + T*(3289.4789+0.60622*T);
	b = 869.8089+0.50491*T;
	sigma = a+d*(-b+d*0.03536);    % en secondes angulaires
	sigma /=3600; % en degres
	sigma *= pi/180.;     % en radians
	a = 5029.0966 + T*(2.22226 - 0.000042*T);
	b = 1.11113-0.000042*T;
	s = d*(a+d*(b-d*0.000006)); % en secondes angulaires
	s = (s/3600)*pi/180.;    % en radians
	l0s = lambda0 - sigma;
	cl0s = cos(l0s); sl0s = sin(l0s);
	cb0 = cos(beta0); sb0 = sin(beta0);
	ceta = cos(eta); seta = sin(eta);
	A = cb0*cl0s;
	B = ceta*cb0*sl0s + seta*sb0;
	C = -seta*cb0*sl0s + ceta*sb0;
	beta = asin (C);
	lambda = s + sigma + atan2(B,A);
endfunction
