function [alfa delta] = chDateCoorEqua(alfa0, delta0, JD0, JD)
% chDateCoorEqua : Changement de date de coordonnees equatoriales
% Usage : [alfa delta] = chDateCoorEqua(alfa0, delta0, JD0, JD);
% Entrees : 
%   alfa0, delta0 : coord. equat a l'epoque initiale en RADIANS
%   JD0 : jour julien dela premiere date (celle des coordonnees alfa0, delta0) 
%   JJ  : jour julien de la date finale (celle des coordonnees a calculer)
% Sorties :
%   alfa, delta : Coordonnees a la date finale, en RADIANS.
	T = (JD0 - 2451545.0)/36525;	% Siècle julien initial par rapport à J2000
	d = (JD-JD0)/36525;   % ecart en siecles juliens	
	a = 2306.2181 + T*(1.39656 - 0.000139*T);
	b = 0.30188-0.000344*T;
	zeta = d*(a+d*(b+d*0.017998)); % en secondes angulaires
	zeta = (zeta/3600)*pi/180.;    % en radians
	b = 1.09468+0.000066*T;
	z = d*(a+d*(b+d*0.018203));    % en secondes angulaires
	z = (z/3600)*pi/180.;          % en radians
	a = 2004.3109 - T*(0.85330 + 0.000217*T);
	b = 0.42665+0.000217*T;
	teta = d*(a+d*(-b-d*0.041883));% en secondes angulaires
	teta = (teta/3600)*pi/180.;    % en radians
	alfa0 += zeta;
	ca0z = cos(alfa0); sa0z = sin(alfa0);
	cd0 = cos(delta0); sd0 = sin(delta0);
	ctet = cos(teta); stet = sin(teta);
	A = ctet*cd0*ca0z - stet*sd0;
	B = cd0*sa0z;
	C = stet*cd0*ca0z + ctet*sd0;
	delta = asin (C);
	alfa = z + atan2(B,A);
endfunction
