function JJ = dmy2jul(j, m, a)
% dmy2jul : Conversion jour decimal, mois, an en jours juliens
% Usage : JJ = dmy2jul(j, m, a)
% Entrees : j = jour decimal de 1.000 a 31.999 (10.5 c'est le 10 a midi)
%           m = mois (1 a 12)
%           a = annee (attention 1 av. J.-C. est note 0, etc..)
% Retour  : JJ = nombre de jours decimaux ecoules depuis le 1/1/-4712 a 12h
% ATTENTION : Une valeur de j entiere correspond a Oh (minuit) et a un JJ se
% terminant par .5. Inversement, une valeur de j se terminant par 0.5
% correspond a 12h (midi) et a une valeur entiere de JJ.
if nargin != 3
	error('dmy2jul necessite 3 arguments : jour decimal, mois, annee !!');
	return
end
% Changement origine des annees pour qu'elles soient > 0 afin que
% les troncatures soient toutes dans le meme sens
    A = a + 4800;
% Changement origine au 1er Mars, afin que la succession des jours
% soit toujours la meme
    M = m; 
	if M <= 2 
		A--; 
		M += 12;
	end
% Correction Julienne/gregorienne 
    if a < 1582 || (a == 1582 && m < 10) || (a == 1582 && m == 10 && j < 15)
		JJ = -38.;
    else
		JJ = floor(A/400) - floor(A/100);
	end
% Decompte avec troncature magique pour les 30/31 et correction des
% changements d'origine 
    JJ += j + floor(36525*A/100) + floor(306*(M+1)/10) - 32167.5;
endfunction