function [ahor, azi, haut] = equa2topo (ad, de, rho, jul, cartes)
% equa2topo : Conversion equatoriales -> coordonnees locales topocentriques
% Usage : [ahor, azi, haut] = equa2topo (ad, de, rho, jul, exact)
% Entrees :
%    ad, de, rho : Coordonnées equatoriales et distance Terre-astre en UA
%    jul    : Date en jour julien temps UNIVERSEL
%    cartes : Si vrai, correction parallaxe topo en cartesien
%             sinon, approximation du 1er ordre
% Sorties : 
%    ahor   : angle horaire de l'astre
%    azi    : azimut
%    haut   : hauteur   
global xOBS zOBS
  if isempty(xOBS), initAstro; endif
  ahor = rAsc2hAng(ad, jul); % Utilisation longitude courante
  if nargin < 5, exact = true; end 
  sde = sin(de); cde = cos(de);
% Correction parallaxe topocentrique
  rho *= 149597870700.;
  if cartes % direct cartésien
     x = rho*cos(ahor)*cde - xOBS;
	y = rho*sin(ahor)*cde; % signe oppose en fait, mais tg(H') idem, ça compense
	z = rho*sde - zOBS;
    ahorPrim = atan2(y, x);
 %   dePrim = asin(z/sqrt(x*x + y*y + z*z)); 
    dePrim = atan(z/sqrt(x*x + y*y)); 
  else % approché au premier ordre
    dho = xOBS*sin(ahor)/(rho*cde)
    dde = (xOBS*cos(ahor)*sde - zOBS*cde)/rho
    ahorPrim = ahor + dho;
    dePrim = de + dde;
  endif
  [azi haut] = hour2hori(ahorPrim, dePrim); % Utilisation latitude courante
endfunction