function [ahor, azi, haut] = equa2topo_full (ad, de, rho, jul, longi, lati, alti)
% equa2topo_full : Conversion equatoriales -> coordonnees locales topocentriques
% Usage : [ahor, azi, haut] = equa2topo (ad, de, rho, jul, longi, lati, alti)
% Entrees :
%    ad, de, rho : Coordonnées equatoriales et distance Terre-astre en UA
%    jul    : Date en jour julien temps UNIVERSEL
%    longi, lati : coordonnees obs en radian
%    alti : altitude observateur en metres
% Sorties (toutes en radians): 
%    ahor   : angle horaire de l'astre
%    azi    : azimut
%    haut   : hauteur   
  [xOBS zOBS] = geo2centre(lati, alti);
  ahor = rAsc2hAng(ad, jul, longi);
  if nargin < 5, exact = true; end 
  sde = sin(de); cde = cos(de);
% Correction parallaxe topocentrique
  rho *= 149597870700.;
  x = rho*cos(ahor)*cde - xOBS;
	y = rho*sin(ahor)*cde; % signe oppose en fait, mais tg(H') idem, ça compense
	z = rho*sde - zOBS;
  ahorPrim = atan2(y, x);
 %   dePrim = asin(z/sqrt(x*x + y*y + z*z)); 
  dePrim = atan(z/sqrt(x*x + y*y)); 
  [azi haut] = hour2hori(ahorPrim, dePrim, lati);
endfunction