function [x z rho latic] = geo2centre(phi, h)
% geo2centre : [latitude, altitude] terrestre -> coordonnées centriques
% ds le plan meridien
% Usage : [x z rho latic] = geo2centre(phi, h)
% Entrees :
%   phi : latitude geodésique (angle normale a l'ellipsoide avec equateur)
%   h   : altitude du lieu
% Sorties :
%   x,z : coordonnées cartesiennes du lieu
%   rho : distance du lieu au centre
%   latic : latitude géocentrique du lieu
% Tous les angles sont en radians et les distances en metres.
a = 6378136.6; % demi-grand axe ellipsoïde terrestre
f = 1./298.257222; % aplatissement
e2 = f*(2.-f); % excentricite au carre
ume2 = 1.-e2; % = (1-f)^2   
sphi = sin(phi);
rs = a/sqrt(1.-e2*sphi*sphi);
x = (rs + h)*cos(phi);
z = (rs*ume2 + h)*sphi;
latic = atan2(z,x);
rho = sqrt(x*x+z*z);
return;