function [heureloc delta] = hori2hour(azimut, hauteur, latitude)
% hori2hour : Conversion coordonnees horizontales en horaires.
% Usage : [heureloc delta] = hori2hour(azimut, hauteur, latitude);
% Entrees :
%    azimut   : azimut de l'astre à partir du sud
%    hauteur  : hauteur de l'astre
%    latitude : latitude de l'observateur (facultative)
% Sorties :
%    heureloc : heure locale de l'astre
%    delta    : declinaison de l'astre
% TOUS les angles sont en RADIANS comptes positifs dans le sens DIRECT
% SAUF heureloc et azimut dans le sens RETROGRADE
global latiCou
if nargin < 3, 
  if isempty(latiCou), initAstro; endif 
  lati = latiCou;
endif
   sP = sin(latitude); cP = cos(latitude);
   sh = sin(hauteur); ch = cos(hauteur)
   cA = cos(azimut);
   delta = asin(sP*sh - cP*cA*ch);
   heureloc = atan2(sin(azimut)*ch, sP*cA*ch + cP*sh);
endfunction