function ju = initAstro(ju, longi, lati, alti, verb)
% initAstro : Initialisation des variables astronomiques
% Usage : ju = initAstro(ju, longi, lati, altitude, verb);
% Entrees facultatives :
%   ju    : jour julien considere. Si absent, heure et jour actuel.
%   longi : longitude du lieu (en radians),si absente, derniere valeur
%   lati  : latitude du lieu (en radians),si absente, derniere valeur
%   alti  : altitude du lieu (en metres),si absente, derniere valeur
%   verb  : Impression diverses info si vrai
% Sortie : (pour une memorisation eventuelle)
%   ju : jour julien courant.
% Un certain nombre de variables courantes sont initialisees, ce qui permet
% d'appeler certaines fonctions en omettants une partie des arguments (en
% queue de liste).
% ATTENTION : Ces valeurs courantes ne sont pas les valeurs qui correspondent
% a l'instant actuel, mais a l'instant fourni en argument, ou en son absence,
% a l'instant de l'appel de la fonction, mais qui n'est pas reactualise et
% qui n'est donc actuel que moment de cet appel. Pour avoir des resultats qui
% corespondent à l'instant actuel, utiliser comme argument jour julien des
% fonctions la valeur julNow().
global longiCou latiCou altiCou xOBS zOBS
global epsCou depsCou dpsiCou
global tsgaCou tslaCou
global exenCou lonSolCou lperiTCou
global AllEOa AllEOb tabVSOP87 sizVSOP87
global bigStars tabStars
global Lune_argDa Lune_argMa Lune_argMla Lune_argFa Lune_sigLa Lune_sigRa
global Lune_argDb Lune_argMb Lune_argMlb Lune_argFb Lune_sigBb
% initialisation des tableaux d'étoiles
if isempty(tabStars), initStars; end
% Initialisations tableaux constantes planétaires
if isempty(AllEOa), makeAllEO; end
if isempty(tabVSOP87), makeVSOP87; end
% Initialisation tableaux constante Lune
if isempty(Lune_argDa), moon_init; end
toRAD = pi/180;
% Initialisation arguments
if nargin < 5, verb = false; endif
if nargin < 4
  if isempty(altiCou), altiCou = 195; end
  alti = altiCou;
end
if nargin < 3
  if isempty(latiCou), latiCou = dms2rad(43,31,31); end
  lati = latiCou;
end
if nargin < 2
  if isempty(longiCou), longiCou = dms2rad(1,34,22); end
  longi = longiCou;
end
if nargin < 1, ju = julNow(); endif
longiCou = longi; latiCou = lati; altiCou = alti;
je = ju + jul2deltaT(ju);
T = jul2juc(je);
% Intitialisation xOBS, zOBS
[xOBS zOBS] = geo2centre(latiCou, altiCou);
% Initialisation obliquité et nutation_cs
[dpsiCou depsCou] = nutationEcli_dg(T, true);
epsCou = obliquity_dg(T) + depsCou;
dpsiCou *= toRAD; depsCou *= toRAD; epsCou *= toRAD;
% Initialisation temps sidéral apparent Greenwich et Local
tsgaCou = jul2mgst_rd(ju)+ dpsiCou*cos(epsCou);
tslaCou = tsgaCou + longiCou;
% Orbite Terre-Soleil
exenCou = eccentricity(T);
lonSolCou = sun_longi_dg(T)*toRAD;
lperiTCou = earth_longiPerih_dg(T)*toRAD;
if nargin > 3 && verb
disp(["Temps universel : " jul2dmy(ju)]);   
disp(["Longitude courante : " rad2dms2(longiCou)]);
disp(["Latitude  courante : " rad2dms2(latiCou)]);
disp(["Obliquité de l'écliptique : " rad2dms(epsCou)]);
disp(["Temps sidéral apparent à Grenwich : " rad2hms(tsgaCou)]);
disp(["Temps sidéral apparent local : " rad2hms(tslaCou)]);
disp(["Excentricité de l'orbite de la Terre : " num2str(exenCou)]);
disp(["Longitude écliptique vraie du Soleil : " rad2dms(lonSolCou)]);
disp(["Longitude du périhélie de la Terre : " rad2dms(lperiTCou)]);
fflush(stdout);
endif
endfunction