function initStars()
% initStars : initialisation des tableau d'étoiles qui sont en global
% Usage : initStars();
global bigStars tabStars
  tabS = loadStars("datas/catalogV50mod.txt");
  if length(tabS) ~= 9110, return; endif
  [bigS, tabS] = lec94StarsNames(tabS);
  bigStars = bigS;
  tabStars = tabS;
endfunction

% Lecture du tableau des 94 étoiles les plus brillantes
function [bigS tabE] = lec94StarsNames(tabE)
  fileIn = fopen("datas/94Stars.txt", "r");
  if fileIn == -1, disp("Echec access fichier des 94 étoiles !"); return; endif
  ok = true;
  n = 0;
  bigS = cell(2,94);
  while ok
    line = fgetl(fileIn);
	  if line == -1, ok = false; break; endif
    % Lecture numero dans le Bright Star Catalogue
	  numStar = str2double(line(1:4));
    % Lecture du nom
	  name = strtrim(line(6:end));
	  if length(name) > 0
		  tabE(numStar).nom = name;
      n++;
		  bigS{1,n} = name; % nom de l'étoile
		  bigS{2,n} = numStar; % son numero dans le tableau V50
	  endif	
  endwhile
  fclose(fileIn);
endfunction

function tabStars = loadStars(fileStars)
% loadStars : Lecture du catalogue d'etoiles ("datas/catalogV50.txt")
% Usage : tabStars = loadStars(fileStars)
  MAXSTARS = 9110;
  tabStars = struct("bsNumber", cell(1,9110), "bsName", "", "flamsteed", 0, "bayer", "", "constel", "", ...
         "vStarId", "", "ad0", 0, "de0", 0, "vMod", 0, "vA", 0, "vD", 0, "mag", 0, "ok", false, "nom", "");
  nbStars = 0;
  fileIn = fopen(fileStars, "r");
  if fileIn == -1, disp("Echec access fichier étoile !"), return; endif
  fprintf(stdout,"La lecture du catalogue d'étoiles est un peu longue, patience ...\n");
  fflush(stdout);
  % Lecture du fichier
  ok = true;
  while ok
    line = fgetl(fileIn);
	  if line == -1, ok = false; break; endif
	  if length(line) < 107, continue; endif % car ligne incomplete
    % Lecture numero V50 de l'étoile dans le catalogue
	  nRead = round(str2double(line(1:4)));
    if (nRead < 1 || nRead > MAXSTARS)
      disp("Numéro d'étoile hors limite du catalogue d'étoiles V50");
      continue;
    endif
	  et = tabStars(nRead);
    et.bsNumber = nRead;
    %Lecture nom (bsName) dans le catalogue
	  strtot = line(5:14);
    if ~strcmp(strtot,"          ")
	    et.bsName = strtot;
	    stra = strtot(1:3); 
	    if ~strcmp(stra,"   "), et.flamsteed = round(str2double(stra)); endif
	    strb = strtot(4:7);
	    if ~strcmp(strb,"    "), et.bayer = strb; endif
      strc = strtot(8:10);
      if ~strcmp(strc,"   "), et.constel = strc; endif
    endif
	  str = line(52:60);
	  if ~strcmp(str,"         "), et.vStarId = str; endif
    % Ascension droite
	  HH = str2double(line(76:77));
	  MM = str2double(line(78:79));
	  SS = str2double(line(80:83));
	  et.ad0 = (15.*(HH + MM/60. + SS/3600.))*pi/180.;
    % Declinaison
	  DD = str2double(line(85:86));
	  MD = str2double(line(87:88));
	  SD = str2double(line(89:90));
	  et.de0 = (DD + MD/60. + SD/3600.)*pi/180.;
	  if (line(84) == '-'), et.de0 = -et.de0; endif
	  % Mouvement propre en ascension droite et declinaison dans J2000 en radians / an
	  vx = str2double(line(149:154))*(pi/180.)/3600.;
	  vy = str2double(line(155:160))*(pi/180.)/3600.;
	  et.vMod = sqrt(vx*vx + vy*vy);
	  et.vA = vx/cos(et.de0);
	  et.vD = vy;
    % Magnitude
	  et.mag = str2double(line(103:107));
    % Signalement étoiles mal renseignées (on ne teste que l'ascension droite)
    if(line(77) == ' ' || line(79) == ' ' || line(81) == ' ') et.ok = false;
    else et.ok = true; endif
	  tabStars(nRead) = et;	
    nbStars += 1;
  endwhile
  if nbStars == MAXSTARS, disp("Lecture complète du catalogue V50.");
  else disp("Lecture incomplète du catalogue V50."); endif
  fclose(fileIn);
endfunction

