function [jdec, mois, an] = jul2jma(JJ)
% jul2dmy : Conversion jour julien en  jour/mois/annee
% Usage : [jdec, mois, an] = jul2dmy(JJ)
% Entree : JJ = date julienne en jours decimaux depuis le Lundi 1/1/-4712 a 12h
% Sortie : 
%    jdec = jour decimal : le 10.5 c'est le 10 a midi. 
%    mois de 1 à 12
%    an = annee ( 1 av. J.-C. est note 0, etc..)
% Attention : jdec termine par .5 quand JJ termine par .0 et reciproquement
% Decompte les siecles depuis le 1.5/3/-4801 en gregorien etendu
% c'est-à-dire le le 7.5/4/-4801 en calendrier julien 
    jj = JJ + 0.5;
    sic = floor((100*jj + 3204500)/3652425);
% Correction bissextiles julienne/gregorienne 
    jjm = jj + 1486;
    if jj > 2299160.5
		jjm += sic - floor(sic/4);
	else 
		jjm += 38;
	end
% Troncatures magiques prenant en compte l'origine au 1er mars
    ans = floor((100*jjm - 12210)/36525);
    jrs = floor((36525*ans)/100);
    mp1 = floor(((jjm - jrs)*100)/3061);
    jdec = jjm - jrs - floor((306*mp1)/10) + JJ + 0.5 - jj;
    mois = mp1 - 1; if (mp1 > 13), mois -= 12; end
    an = ans - 4715; if (mois > 2), an -= 1; end
endfunction