function [M] = matChDateCoorEcli(JD0, JD1)
% matChDateCoorEcli : Matrice de changement de date pour coord. ecliptique
% Usage : [M] = matChDateCoorEcli(JD0, JD1);
% Entrees :
%   JD0  : jour julien de la premiere date 
%   JD1  : jour julien de la deuxieme date
% Sortie :
%   La matrice M telle que (V)_1 = M (V)_0
	T = (JD0 - 2451545.0)/36525;	% Siecle julien initial par rapport a J2000
	d = (JD1-JD0)/36525;   % beta t entre dates initiale et finale en siecles j.
	a = 47.0029 + T*(-0.06603 + 0.000598*T);
	b = -0.03302+0.000598*T;
	eta = d*(a+d*(b+d*0.00006)); % en secondes angulaires
	eta = (eta/3600)*pi/180.;    % en radians
	a = 174.876384*3600 + T*(3289.4789+0.60622*T);
	b = 869.8089+0.50491*T;
	sigma = a+d*(-b+d*0.03536);    % en secondes angulaires
	sigma /=3600; % en degres
	sigma *= pi/180.;     % en radians
	a = 5029.0966 + T*(2.22226 - 0.000042*T);
	b = 1.11113-0.000042*T;
	s = d*(a+d*(b-d*0.000006)); % en secondes angulaires
	s = (s/3600)*pi/180.;    % en radians
	M = mrotZ(s+sigma)*mrotX(-eta)*mrotZ(-sigma);
endfunction