function [M] = matChDateCoorEqua(JD0, JD1)
% matChDateCoorEqua : Matrice de changement de date pour coord. equatoriales
% Usage : [M] = matChDateCoorEqua(JD0, JD1);
% Entrees :
%   JD0  : jour julien de la premiere date 
%   JD1  : jour julien de la deuxieme date
% Sortie :
%   La matrice M telle que (V)_1 = M (V)_0
	T = (JD0 - 2451545.0)/36525; % Siècle julien initial par rapport à J2000
	d = (JD1-JD0)/36525;   % Delta t entre dates initiale et finale en siècles j.
	a = 2306.2181 + T*(1.39656 - 0.000139*T);
	b = 0.30188-0.000344*T;
	zeta = d*(a+d*(b+d*0.017998)); % en secondes angulaires
	zeta = (zeta/3600)*pi/180.;    % en radians
	b = 1.09468+0.000066*T;
	z = d*(a+d*(b+d*0.018203));    % en secondes angulaires
	z = (z/3600)*pi/180.;          % en radians
	a = 2004.3109 - T*(0.85330 + 0.000217*T);
	b = 0.42665+0.000217*T;
	teta = d*(a+d*(-b-d*0.041883));% en secondes angulaires
	teta = (teta/3600)*pi/180.;    % en radians
	M = mrotZ(z)*mrotY(-teta)*mrotZ(zeta);
endfunction