function [ra, de, distTL]  = moon_je2equa(JD, verbose)
% moon_je2equa : Coordonnees equatoriales geocentriques de la Lune
%             dans le repere equatorial equinoxe de la date
% Usage : [ra, de, distTL]  = moon_je2equa(JD, verbose);
% Entrees :
%    JD      : date du calcul en jour julien des ephemerides
%    verbose : Impression des infos sur la Lune si vrai
% Sorties :
%    ra, de  : coordonnees equatoriales apparentes 
%    rho     : distance a la Terre en metres
% Les angles sont en radians et les distances en metres
if nargin < 2, verbose = false; endif
  [xyz lbr] = moon_je2eclip(JD);
  distTL = lbr(3);
  T = jul2juc(JD);
  % Correction nutation en coordonnées ecliptiques
  [dpsi_dg dobliq_dg] = nutationEcli_dg(T, true);
  longi = lbr(1) + dpsi_dg*pi/180.;	
% Coordonnees equatoriales vraies a la date
  obliq =  (obliquity_dg(T) + dobliq_dg)*pi/180;
  [ra de] = ecli2equa(longi, lbr(2), obliq);
  if nargin < 2, verbose = false; endif
  if verbose
	  printf("Distance Terre-Lune : %11.3f km\n", distTL/1000.);
    printf("AD et DE apparentes : %s, %s\n",...
             rad2hms(ra), rad2dms2(de));  
  endif   
endfunction