function [jlev, jtra, jcou] = moon_transit(ju, longiA, latiA)
h0 = 0.125*pi/180; % hauteur au lever ou coucher
sinh0 = sin(h0);
jtra = -1; jlev = -1; jcou = -1;
%% Constantes ou données initiales
if nargin < 3, latiA = dms2rad(43,36,15); endif
if nargin < 2, longiA = dms2rad(1,26,37); endif
if nargin < 1, ju = julNow(); endif
omegaT = (360.98564736629/360.)*2*pi; % vrot_terre rd/jours
% Arret des itérations a 0.1 s près.
epstest = 0.5/86400; % 1/2 s en jour
% jour julien de la date d'observation UT à midi
jref = floor(ju + 0.5);
DeltaT = jul2deltaT(jref);
% Ascension droite méridien local à jref
Aref = jul2agst_rd(jref) + longiA;
% Postion de la Lune à jref UT
[ra dec rho] = moon_je2equa(jref + DeltaT, false);
deltaAsc = realmod2(ra - Aref, 2*pi);
jtransit = jref + deltaAsc/omegaT;
cosH = (sinh0 - sin(latiA)*sin(dec))/(cos(latiA)*cos(dec));
if cosH < 0, return; endif % pas de solution
H = acos(cosH);
jlever = jref + (deltaAsc - H)/omegaT;
jcoucher = jref + (deltaAsc + H)/omegaT;
for i=1:10
  jtransit_old = jtransit; 
  jlever_old = jlever;  
  jcoucher_old = jcoucher;  
  [ra dec rho] = moon_je2equa(jref + DeltaT, false);
  jtransit = jref + realmod2(ra - Aref, 2*pi)/omegaT;
  % Postion du soleil le matin
  [ra dec rho] = moon_je2equa(jlever + DeltaT, false); 
  cosHlev = (sinh0 - sin(latiA)*sin(dec))/(cos(latiA)*cos(dec));
  jlever = jref + (realmod2(ra - Aref, 2*pi) - acos(cosHlev))/omegaT;
  % Postion du soleil le soir
  [ra dec rho] = moon_je2equa(jref + DeltaT, false);
  cosHcou = (sinh0 - sin(latiA)*sin(dec))/(cos(latiA)*cos(dec));  
  jcoucher = jref + (realmod2(ra - Aref, 2*pi) + acos(cosHcou))/omegaT;
  if (abs(jlever_old-jlever) < epstest && abs(jcoucher_old-jcoucher) < epstest ...
                                   && abs(jtransit_old-jtransit) < epstest)
    break;
  endif
endfor
jtra = jtransit;
jlev = jlever;
jcou = jcoucher;
endfunction
