function [dpsi deps] = nutationEcli_dg(T, super)
% nutationEcli_dg : Calcul des corrections ecliptiques de nutation (dg)
% Usage : [dpsi deps] = nutationEcli_dg(T, super);
% Entrees (facultatives :
%	  T     : siecle julien du calcul = (JD-2451545)/36525;
%   super : vrai si grande precison demandee
% Sorties :
%	  dpsi  : Variation de longitude ecliptique de l'axe des poles celeste
%   deps  : Variation d'obliquite de l'axe des poles celeste

if nargin < 2, super = false; endif
if nargin < 1
  ju = julNow(); je = ju + jul2deltaT(ju); T = jul2juc(je);
end
	torad = pi/180.;
if super 
	D  = 297.85036 + T*(445267.111480 + T*(-0.0019142 + T/189474));
	M  = 357.52772 + T*(35999.050340 + T*(-0.0001603 - T/300000));
	Mp = 134.96298 + T*(477198.867398 + T*(0.0086972 + T/56250));
	F  =  93.27191 + T*(483202.017538 + T*(-0.0036825 + T/327270));
	O  = 125.04452  +T*(-1934.136261 + T*(0.0020708  + T/450000));
	D *= torad;	M *= torad;	Mp *= torad;	F *= torad;	O *= torad;
	Lp = F + O;	L = Lp - D; 
	dpsi = -(171996+174.2*T)*sin(O)-(13187+1.6*T)*sin(2*L)-(2274+0.2*T)*sin(2*Lp)...
	+(2062+0.2*T)*sin(2*O)+(1426-3.4*T)*sin(M)+(712+0.1*T)*sin(Mp)+(-517+1.2*T)*sin(2*L+M)...
	-(386+0.4*T)*sin(Lp+F)-301*sin(2*Lp+Mp)+(217-0.5*T)*sin(2*L-M)-158*sin(Mp-2*D)...
	+(129+0.1*T)*sin(2*L-O)+123*sin(2*Lp-Mp)+63*sin(2*D);
	deps =  (92025+8.9*T)*cos(O)+(5736-3.1*T)*cos(2*L)+(977-0.5*T)*cos(2*Lp)...
	+(-895+0.5*T)*cos(2*O)+(54-0.1*T)*cos(M)-7*cos(Mp)+(224-0.6*T)*cos(2*L+M)...
	+200*cos(Lp+F)+(129-0.1*T)*cos(2*Lp+Mp)+(-95+0.3*T)*cos(2*L-M)-70*cos(2*L-O)-53*cos(2*Lp-Mp);
	fromdeg = 10000*3600;
  dpsi /= fromdeg;
	deps /= fromdeg;
else
	O = 125.04452  - 1934.136261*T;
  L = 280.4665 + 36000.7698*T;
  Lp = 218.3165 + 481267.8813*T;
  O *= torad;	L *= torad;	Lp *= torad; dL = 2.*L; dLp = 2.*Lp; dO = 2.*O;
  dpsi = -17.20*sin(O) - 1.32*sin(dL) - 0.23*sin(dLp) + 0.21*sin(dO);
  deps =   9.20*cos(O) + 0.57*cos(dL) + 0.10*cos(dLp) - 0.09*cos(dO);
  dpsi /= 3600.;
  deps /= 3600.;
endif
endfunction