function [ahor, decli, azi, haut] = planet_info(npla, ju, refrac, nimp, deltas)
% star_info : Informations sur une planete
% Usage : [ahor, decli, azi, haut] = planet_info (n, ju, nimp, deltas);
% Entrees :
%    n      : numero planete : 1 Mercure, 2 Venus, ...       
%    ju    : Date en jour julien temps universel
%    refrac : Si vrai :correction refrac
%    nimp   : Nombre d'impression des coordonnees locales
%    deltas : Intervalle de temps en sec. entre les dates d'impression.
%             Limite a 10s si ju = julNow, pour limiter l'attente si erreur
% Sorties : 
%    ahor   : angle horaire de la planete
%    decli  : declinaison
%    azi    : azimut
%    haut   : hauteur 
% Remarque : Pour npla = 3 on donne les coordonnees du Soleil.

  nompla = {"Mercure","Vénus","Soleil","Mars","Jupiter","Saturne","Uranus","Neptune"};
  if nargin < 2, ju = julNow(); end
  je = ju + jul2deltaT(ju);
  ddd = (julNow-ju)*86400; now = (ddd >= 0) && (ddd < 0.5);
  if npla < 1 || npla > 8, disp("Planete non trouvée !"); return; endif 
  [alpha decli rho] = planet_je2equa(je, npla, true, true);
  if nargin < 5, deltas = 1.; endif % 1 seconde d'intervalle par défaut
  if nargin < 4, nimp = 1; endif 
  if nargin < 3, refrac = false; endif 
  if npla ~= 3
     printf("Informations sur %s\n", nompla{npla});  
  else
     printf("Informations sur le Soleil\n");
  endif
  % Impression pour une date quelconque
  if !now || nimp == 1
    printf("  Angle horaire   Déclinaison   Azimut       Hauteur\n");    
	  for k = 1:nimp
      [ahor, azi, haut] = equa2topo (alpha, decli, rho, ju, true);
	  % Correction réfraction
      if refrac, haut += refraction_dg(haut*180/pi, true)*pi/180.; endif
      printf(" %s   %s   %s  %s\n",...
             rad2hms2(ahor), deg2str2(decli*180/pi), deg2str2(azi*180/pi),...
             deg2str2(haut*180/pi)); 
      ju += deltas/86400.;             
    endfor
    fflush(stdout);
	return
  else
    if nimp <= 0, nimp = 10; endif
    if deltas > 10, delats = 10.; endif  
    disp('Taper une touche pour arrêter si trop long !')
    printf("  Angle horaire   Declinaison   Azimut       Hauteur\n");
    for k = 1:nimp 
      % Coordonnées locales    
     [ahor, azi, haut] = equa2topo (alpha, decli, rho, ju, true);
      % Correction réfraction
      haut += refraction_dg(haut*180/pi, true)*pi/180.; 	  
      printf("\r %s   %s   %s  %s",...
             rad2hms2(ahor), deg2str2(decli*180/pi), deg2str2(azi*180/pi),...
             deg2str2(haut*180/pi)); 
      fflush(stdout);         
	    if length(kbhit(1)) > 0, break; endif    
      sleep(deltas-1); 
	    jold = ju - 10*eps;
	    julp = ju+deltas/86400.;
	    while (julp > ju && ju >= jold)
	      ju = julNow();
		  usleep(10000);
	    endwhile
    endfor 
    printf("\n");
    fflush(stdout); 
  endif   
endfunction
