function [XYZ LBR] = planet_je2eclipG(npla, JD, xyzT, flagVSOP87)
% PAS FINI - C'EST TOUJOURS HELIOCENTRIQUE !!!!!!!!!
% planet_je2eclipG : Calcul des coordonnees ecliptiques geocentriques d'une
% des 8 planetes dans le repere equinoxe moyen de la date
% Usage : [XYZ LBR] = planet_je2eclipG(npla, JD, xyzT, flagVSOP87)
% Entrees :
%	 npla : numero de la planete (1 a 8) 
%	 JD   : Date courante en jour julien des ephemerides
%    xyzT : coordonnees ecliptiques heliocentriques de la Terre
%    flagVSOP87 : Si vrai calcul par theorie VSOP87
% Sorties :
%   XYZ : Coordonnees cartesiennes de la planete en UA dans le repere ecliptique
%	LBR : {L, B, R}, a savoir :
%		L : longitude ecliptique en radians
%		B : latitude ecliptique en radians
%		R : distance au Soleil en unite astronomique
if flagVSOP87
  XYZ = jePla2elipHvsop(npla, JD) - xyzT;
else 
  XYZ = planet_je2eclipHbis(npla, JD, true, true) - xyzT;
endif
% Coordonnées ecliptiques
   rho = norm(XYZ);
   lambda = atan2(XYZ(2),XYZ(1));
   beta = asin(XYZ(3)/rho);
   LBR = [lambda beta rho];
endfunction