function [XYZ LBR] = planet_je2eclipHvsop(npla, JD)
% planet_je2eclipHvsop : Coordonnees ecliptiques heliocentriques d'une planete 
% rapportees a l'equinoxe moyen de la date
% Usage : [XYZ LBR] = planet_je2eclipHvsop(npla, JD);
%Entrees :
%	npla : numero de la planete (1 a 8) 
%	JD : Date en jour julien des ephemerides
%Sorties :
%   XYZ : Coordonnees cartesiennes de la planete en UA dans le repere ecliptique
%	LBR = {L, B, R}, a savoir :
%		L : longitude ecliptique en radians
%		B : latitude ecliptique en radians
%		R : distance au Soleil en unite astronomique
global tabVSOP87 sizVSOP87
  if isempty(tabVSOP87)
		makeVSOP87; 
  end
  T = (JD - 2451545) / 365250; % En millenaires juliens depuis J2000.
  LBR = zeros(1,3);
  for m = 1:3 %% pour les 3 coordonnees L, B, R
	res = 0.;
	for k = 6:-1:1 %% Coefficients 0 a 5 de L, B ou R, en ordre inverse pour schema de Horner
		CoefI = tabVSOP87{(m-1)*8+npla, k}; 
		nn = sizVSOP87((m-1)*8+npla,k);
		%% Sommation pour calcul de chacun des 6 coefs Li, Bi ou Ri, i = 0 a 5
		coef = 0.;
		for n = 1:nn
			coef += CoefI(n,1) * cos(CoefI(n,2) + CoefI(n,3)*T);
		end
		res = coef + res*T; %% schema de Horner
	end
	LBR(m) = res/100000000;
  end
  % recadrage longitude dans un tour.
  LBR(1) = mod(LBR(1)+pi, 2*pi) - pi;
  cB = cos(LBR(2));
  XYZ = LBR(3)*[cos(LBR(1))*cB sin(LBR(1))*cB sin(LBR(2))];
endfunction