function [dh] = refraction_dg(h, th2ap, T, P)
% refraction_dg : Variation de hauteur due a la refaction
% Usage : [dh] = refraction_dg(h, th2ap, T, P);
% Entrees :
%   h : hauteur theorique ou apparente en degres
% Entrees facultatives :
%   th2ap : si vrai h est theorique (cad vraie), et apparente si faux
%    T    : temperature en Celsius (faculative)
%    P    : pression en millibar (facultative)
% Sortie :
%    dh   : variation de hauteur
% Remarque :
%   Si th2ap est vrai, h = hTheorique ou vrai (par defaut)
%   Si th2ap est faux, h = hApparent ou observee
%   avec dh = hApparent - hTheorique dans les deux cas.
if nargin < 2, th2ap = true; endif
K = 1;
if nargin > 2, K = 283/(T+273); end
if nargin > 3, K *= P/1010; end
if th2ap
  arg = h + 10.3/(h + 5.1);
  if arg < 90
    arg *= pi/180.;  
    dh = K*(1.02/tan(arg))/60.;
  else dh = 0; end
else
  arg = h + 7.31/(h + 4.4);
  if arg < 90
    arg *= pi/180.;
    dh = K*(1./tan(arg))/60.;
  else dh = 0; end
end
endfunction