function sat = sat_2local(sat, ju, longi, lati, alti)
% sat_2local : Calcul de la position satellite dans un repère observateur
% Usage : sat_2local(sat, ju, longi, lati, alti)
% Entrees :
%   sat : le satellite avec sa position dans Rc centre Terre deja a jour.
%   ju  : l'instant julien en temps TU.
%   longi, lati : coordonnees observateur en radians
%   alti : altitude observateur en metres
% Sorties : 
%   sat : le satellite dont les champs suivants sont calculés :
%     adLoc = ascension droite telle que perçue localement
%     decLoc = declinaison telle que perçue localement
%     ahLoc = angle horaire perçu localemebt
%     aziLoc = azimut perçu localement
%     sitLoc = hauteur perçue localement;
%     distLoc = distance à l'observateur
%
  % Position observateur dans Rc
  [x z] = geo2centre(lati, alti);
  ang = jul2agst_rd(ju) + longi;
  y = x*sin(ang); x *= cos(ang);
  % Vecteur Obs-Sat dans Rc centre observateur
  x = sat.v3_TS_c(1) - x;
  y = sat.v3_TS_c(2) - y;
  z = sat.v3_TS_c(3) - z;
  d = sqrt(x*x+y*y+z*z);
  % AD et DEC locales
  ad = atan2(y, x);
  dec = asin(z/d);
  % angle horaire local
  ah = ang - ad;
  % azimut et hauteur
  sh = sin(ah); 
  ch = cos(ah);
  sd = sin(dec); 
  cd = cos(dec);
  sp = sin(lati); 
  cp = cos(lati);
  azi = atan2(sh*cd, ch*sp*cd - sd*cp);
  haut = asin(sp*sd + cp*cd*ch);
  sat.adLoc = ad;
  sat.decLoc = dec;
  sat.ahLoc = ah;
  sat.aziLoc = azi;
  sat.sitLoc = haut;
  sat.distLoc = d;
endfunction
