function sat_info(sat, ju, refrac, nimp, deltas)
% sat_info : Informations sur un satellite
% Usage : sat_info (sat, ju, nimp, deltas);
% Entrees :
%    sat    : nom d'un satellite dont la tle sera recherchee sur le web
%             ou mieux structure de ce satellite si on la deja instanciee      
%    ju     : Date en jour julien temps universel
%    refrac : Si vrai :correction refrac
%    nimp   : Nombre d'impression des coordonnees locales
%    deltas : Intervalle de temps en sec. entre les dates d'impression.
%             Limite a 10s si ju = julNow, pour limiter l'attente si erreur
% Sorties : 
%    ahor   : angle horaire du satellite
%    decli  : declinaison
%    azi    : azimut
%    haut   : hauteur 

  if nargin < 2, ju = julNow(); end
  je = ju + jul2deltaT(ju);
  ddd = (julNow-ju)*86400; 
  now = (ddd >= 0) && (ddd < 0.5);
  if ischar(sat)
	newsat = sat_find(sat);
	if isempty(newsat), disp("Satellite non trouvé !"); return; endif
	sat = newsat;
  endif
%  sat = sat_update(sat,ju);
%  alpha = sat.ascen_droite;
%  decli = sat.declinaison;
%  rho = sat.distTS;
  if nargin < 5, deltas = 1.; endif % 1 seconde d'intervalle par défaut
  if nargin < 4, nimp = 1; endif 
  if nargin < 3, refrac = false; endif 
  % Impression pour une date quelconque
  sat = sat_update(sat, ju);  
  printf("Informations (centrales) sur le satellite %s\n",sat.name);
  if !now || nimp == 1
    printf("distance(km)   longitude           déclinaison\n");    
	  for k = 1:nimp
      sat = sat_update(sat, ju);
      printf("%d     %s      %s\n",sat.distTS/1000.,...
             rad2dms2(sat.ascen_droite),rad2dms2(sat.declinaison)); 
      ju += deltas/86400.;             
    endfor
    fflush(stdout);
	return
  else
    if nimp <= 0, nimp = 10; endif
    if deltas > 10, delats = 10.; endif  
    disp('Taper une touche pour arrêter si trop long !')
    printf("distance(km)   longitude           déclinaison\n");   
    for k = 1:nimp 
      sat = sat_update(sat, ju);
      printf("%d     %s      %s\n",sat.distTS/1000.,...
             rad2dms2(sat.ascen_droite),rad2dms2(sat.declinaison)); 
      fflush(stdout);         
	    if length(kbhit(1)) > 0, break; endif    
      sleep(deltas-1); 
	  jold = ju - 10*eps;
	  julp = ju+deltas/86400.;
	  while (julp > ju && ju >= jold)
	    ju = julNow();
		usleep(10000);
	  endwhile
    endfor 
    printf("\n");
    fflush(stdout); 
  endif   
endfunction
