function sat_infoLoc(sat, ju, refrac, nimp, deltas, longi, lati, alti)
% sat_info : Informations sur un satellite
% Usage : sat_infoLoc(sat, ju, refrac, nimp, deltas, longi, lati, alti)
% Entrees :
%    sat    : nom d'un satellite dont la tle sera recherchee sur le web
%             ou mieux structure de ce satellite si on la deja instanciee      
%    ju     : Date en jour julien temps universel
%    refrac : Si vrai :correction refrac
%    nimp   : Nombre d'impression des coordonnees locales
%    deltas : Intervalle de temps en sec. entre les dates d'impression.
%             Limite a 10s si ju = julNow, pour limiter l'attente si erreur
%     longi, lati : coordonnes observateur en radians
%     alti : altitude observateur en metres
% Sorties : 
%    ahor   : angle horaire du satellite
%    decli  : declinaison
%    azi    : azimut
%    haut   : hauteur 
global longiCou latiCou altiCou
  if nargin < 8
    if isempty(altiCou), alti = 195; else, alti = altiCou; endif
  endif
  if nargin < 7  
    if isempty(latiCou), lati = dms2rad(43,31,31); else, lati = latiCou; endif
  endif
  if nargin < 6
    if isempty(longiCou), longi = dms2rad(1,34,22); else, longi = longiCou; endif
  endif
  if nargin < 5, deltas = 1.; endif % 1 seconde d'intervalle par défaut
  if nargin < 4, nimp = 1; endif 
  if nargin < 3, refrac = false; endif 
  if nargin < 2, ju = julNow(); end
  ddd = (julNow-ju)*86400; 
  now = (ddd >= 0) && (ddd < 0.5);
  if ischar(sat)
	newsat = sat_find(sat);
	if isempty(newsat), disp("Satellite non trouvé !"); return; endif
	sat = newsat;
  endif
  % Impression pour une date quelconque
  printf("Informations (locales) sur le satellite %s\n",sat.name);
  if !now || nimp == 1
    printf(" Asc. Droite   Declinaison   Angle horaire   Azimut      Hauteur\n");  
	  for k = 1:nimp
      sat = sat_2local(sat_update(sat,ju), ju, longi, lati, alti);
      haut = sat.sitLoc;;
	  % Correction réfraction
      if refrac, haut += refraction_dg(haut*180/pi, true)*pi/180.; endif
      printf("%s %s %s %s %s\n",...
             rad2hms(sat.adLoc), rad2dms2(sat.decLoc),...
             rad2hms2(sat.ahLoc), rad2dms2(sat.aziLoc),...
             deg2str2(haut*180/pi)); 
      ju += deltas/86400.;             
    endfor
    fflush(stdout);
	return
  else
    if nimp <= 0, nimp = 10; endif
    if deltas > 10, delats = 10.; endif  
    disp('Taper une touche pour arrêter si trop long !')
    printf(" Asc. Droite   Declinaison   Angle horaire   Azimut      Hauteur\n");  
    for k = 1:nimp 
      sat = sat_2local(sat_update(sat,ju), ju, longi, lati, alti);
      haut = sat.sitLoc;;
	  % Correction réfraction
      if refrac, haut += refraction_dg(haut*180/pi, true)*pi/180.; endif
      printf("%s %s %s %s %s\n",...
             rad2hms(sat.adLoc), rad2dms2(sat.decLoc),...
             rad2hms2(sat.ahLoc), rad2dms2(sat.aziLoc),...
             deg2str2(haut*180/pi)); 
      fflush(stdout);         
	    if length(kbhit(1)) > 0, break; endif    
      sleep(deltas-1); 
	  jold = ju - 10*eps;
	  julp = ju+deltas/86400.;
	  while (julp > ju && ju >= jold)
	    ju = julNow();
		usleep(10000);
	  endwhile
    endfor 
    printf("\n");
    fflush(stdout); 
  endif   
endfunction
