function sat = sat_update(sat, ju)
% sat_update : Calcul de la position et vitesse d'un satellite dans le repère céleste centre Terre
% Usage : sat = sat_update(sat, ju);
% Entrees :
%   sat : la structure du satellite
%    ju : date julienne UT pour laquelle on ddesire la position
% Sortie :
%   sat : Tous les champs variables avec le temps sont mis à jour :
%    m3_CL      : Matrice passage celeste -> orbital local
%    v3_Oml_c   : Vitesse rotation repere orbital local Rl / Rc
%    ascen_droite,
%    declinaison,
%    distTS     : distance Centre Terre - satellite
%    m3_GL      : Matrice de passage Greenwich -> orbital local
%    longitude,
%    v3_TS_c    : position cartesienne satellite dans Rc
%    v3_Vs_c    : vitesse translation satellite dans Rc
% Rappel : Repere orbital local : 
%    X selon Vit, Y selon Hcin, Zl selon Terre->Sat
    t = (ju - sat.ju0)*86400; % Nb de secondes depuis ju0
    grand_Omega = sat.gdOm0 + sat.gdOmP*t;
    petit_omega = sat.om0 + sat.omP*t;
    %Mouvement moyen
    n = sat.n0 + t*(2.*sat.n0dots2 + t*3.*sat.n0ddots6);
    a = sat.a0 * (sat.n0/n)^(2./3.);
    e = 1. - sat.a0*(1. - sat.e0)/a;
    if (e < 0.) e = 0.; endif
    unme2 = 1.- e*e;
    p = a*unme2;
    sq_unme2 = sqrt(unme2);
    sq_unme3s2 = unme2*sq_unme2;
    anoMoy_M = sat.M0 + t*(sat.n0 + t*(sat.n0dots2 + t*sat.n0ddots6));
    % Resolution equation de Kepler par iterations
    cpo = cos(petit_omega);
    spo = sin(petit_omega);
    anoExc_E = anoMoy_M;
    for iter = 1:4; 
        dM = anoMoy_M - (anoExc_E - e*sin(anoExc_E));
        if abs(dM) < 1.e-12, break; endif
        dE = dM / (1. - e*cos(anoExc_E) ) ;
        anoExc_E += dE;
		if abs(dE) < 1.e-12, break; end 
    endfor
    cE = cos(anoExc_E); 
	sE = sin(anoExc_E);
	umecE = 1. - e*cE;
    cv = (cE - e)/umecE;
    sv = sq_unme2*sE/umecE;
    anoVraie_v = atan2(sv,cv);
    unpecosv = 1. + e*cv;
    sat.distTS = p/unpecosv;
    pso = petit_omega + anoVraie_v;
    ct = cos(pso); st = sin(pso);
    temp = a*n/sq_unme2;
	% Vitesse translation du satellite dans Rc
    v3_Vs_n = [-temp*(st + e*spo); temp*(ct + e*cpo); 0.];
    % Attitude Rn / Rc
    cgo = cos(grand_Omega);
    sgo = sin(grand_Omega);
	  m3_CH = [cgo -sgo 0; sgo  cgo  0; 0  0  1];
    m3_CN = m3_CH*sat.m3_HN;
    % Attitude repere orbital local Rl / Rc
    % X selon Vit, Y selon Hcin, Zl selon TS
    m3_NL = [-st 0 ct; ct 0 st; 0 1 0];
	  sat.m3_CL = m3_CN*m3_NL;
    % Vitesse rotation repere orbital local Rl / Rc
    vP = n*unpecosv*unpecosv/sq_unme3s2;
    temp = sat.omP + vP;
    sat.v3_Oml_c = [temp*m3_CN(1,3); temp*m3_CN(2,3); temp*m3_CN(3,3) + sat.gdOmP];
    sat.ascen_droite = atan2(sat.m3_CL(2,3), sat.m3_CL(1,3));
    sat.declinaison = asin(sat.m3_CL(3,3));
    hsg = jul2mgst_rd(ju);
    coshsg = cos(hsg);
    sinhsg =  sin(hsg);
	  terre_m3_GC = [coshsg sinhsg 0; -sinhsg coshsg 0; 0 0 1];
    sat.m3_GL = terre_m3_GC*sat.m3_CL;
    sat.longitude = atan2(sat.m3_GL(2,3), sat.m3_GL(1,3));
    % Position et vitesses satellite dans Rc
    sat.v3_TS_c = sat.distTS*[ sat.m3_CL(1,3) ; sat.m3_CL(2,3) ; sat.m3_CL(3,3)];
    sat.v3_Vs_c = m3_CN * v3_Vs_n;
endfunction
