function [ahor, decli, azi, haut] = star_info (star, jul, nimp, deltas)
% star_info : Informations sur une etoile
% Usage : [ahor, decli, azi, haut] = star_info (star, jul, nimp, deltas);
% Entrees :
%    star   : Soit le nom d'une des 94 etoiles brillantes (liste par stars_Blist)
%              soit un numero du catalogue V50 (1 <= star <= 9110)
%    jul    : Date en jour julien temps universel
%    nimp   : Nombre d'impression des coordonnees locales
%    deltas : Intervalle de temps en sec. entre les dates d'impression.Limite
%             a 10s si jul = julNow (en cas d'erreur, pour limiter l'attente)
% Sorties : 
%    ahor   : angle horaire de l'etoile
%    decli  : declinaison
%    azi    : azimut
%    haut   : hauteur 
  if nargin < 2, jul = julNow; endif  
  ddd = (julNow-jul)*86400; now = (ddd > 0) && (ddd < 0.5);
  etoile = star_find(star);
  if isempty(etoile), disp("Etoile non trouvée !"); return; endif 
  [alpha decli] = star_je2equa(jul+jul2deltaT(jul), etoile, true);
  if nargin < 4, deltas = 1.; endif % 1 seconde d'intervalle par défaut
  if nargin < 3, nimp = 1; endif   
  printf("Informations sur l'étoile %s\n", etoile.nom);  
  % Impression pour une date quelconque
  if !now || nimp == 1
    printf("  Angle horaire   Déclinaison   Azimut       Hauteur\n");    
	  for k = 1:nimp
      [ahor, azi, haut] = equa2local (alpha, decli, jul);
	  % Correction réfraction
      dh_dg = refraction_dg(haut*180/pi, true);
      hautcr = haut + dh_dg*pi/180.; 
      printf(" %s   %s   %s  %s\n",...
             rad2hms2(ahor), deg2dms2(decli*180/pi), deg2dms2(azi*180/pi),...
             deg2dms2(hautcr*180/pi)); 
      jul += deltas/86400.;             
    endfor
    fflush(stdout);
	return
  else
    if nimp <= 0, nimp = 10; endif
    if deltas > 10, delats = 10.; endif  
    disp('Taper une touche pour arrêter si trop long !')
    printf("  Angle horaire   Declinaison   Azimut       Hauteur\n");
    for k = 1:nimp 
      % Coordonnées locales    
      [ahor, azi, haut] = equa2local (alpha, decli, jul);
 	  % Correction réfraction
      hautcr = haut + refraction_dg(haut*180/pi, true)*pi/180.;       
      printf("\r %s   %s   %s  %s",...
             rad2hms2(ahor), deg2dms2(decli*180/pi), deg2dms2(azi*180/pi),...
             deg2dms2(hautcr*180/pi)); 
       
      fflush(stdout);         
	    if length(kbhit(1)) > 0, break; endif    
      sleep(deltas-1); 
	    jold = jul - 10*eps;
	    julp = jul+deltas/86400.;
	    while (julp > jul && jul >= jold)
	      jul = julNow();
		    usleep(10000);
	    endwhile
    endfor 
    printf("\n");
    fflush(stdout);
  endif   
endfunction
