% star_ju2transit : date julienne UT des lever, transit et coucher d'une étoile
% longiA, latiA en radians
function [jlev, azilev, jtra, htra, jpon, azipon] = star_ju2transit(ju, nom, longiA, latiA, impr)
jtra = -1; jlev = -1; jpon = -1;
azipon = 0.; azilev = 0.;
%% Traitement lieu d'observation
global longiCou latiCou
if nargin < 4,
  if isempty(latiCou), initAstro; endif
  latiA = latiCou; 
endif
if nargin < 3, longiA = longiCou; endif
%% Traitement nom de l'astre
 star = star_find (nom);
 if isempty(star), disp("Etoile non trouvée :"); return; endif
%% Hauteur de l'astre au début de sa visibilité
%% et instant proche du transit
h0 = -0.5667*pi/180.; %Refraction au niveau de l'horizon
jref = floor(ju + 0.5) +0.5; % minuit local de ce jour
jref -=  longiA/(2.*pi); % date UT pour date locale
sinh0 = sin(h0);
sinPhiA = sin(latiA); cosPhiA = cos(latiA);
%% Constantes ou données initiales
omegaT = (360.98564736629/360.)*2*pi; % vrot_terre rd/jours
DeltaT = jul2deltaT(jref);
% Ascension droite méridien local à jref
Aref = jul2agst_rd(jref) + longiA;
% Postion de l'astre à jref UT
[raSref dec] = star_je2equa(jref + DeltaT, star, false);
htra = pi/2 - abs(latiA - dec);
cosDec = cos(dec);
sinDec = sin(dec);
deltaAsc = realmod2(raSref - Aref, 2*pi);
jtra = jref + deltaAsc/omegaT;
if impr
  printf("Date transit : %s\n", jul2dmy(jtra));
  printf("Hauteur transit : %s\n", rad2dms2(htra));
endif
cosH = (sinh0 - sinPhiA*sinDec)/(cosPhiA*cosDec);
if abs(cosH) > 1
   if  htra < h0 
      disp("Etoile toujours sous l'horizon !"); 
   else
      disp("Etoiletoujours au-dessus de l'horizon !"); 
  endif
  return; 
endif % pas de solution
H = acos(cosH); % +H couchant, -H levant
sinH = sin(H);
jlev = jref + (deltaAsc - H)/omegaT;
jpon = jref + (deltaAsc + H)/omegaT;
azipon = atan2(sinH, sinPhiA*cosH - cosPhiA*sinDec/cosDec);
azilev = -azipon;
if impr
  printf("Date lever : %s\n", jul2dmy(jlev));
  printf("Azimut lever : %s\n", rad2dms(azilev));  
  printf("Date coucher : %s\n", jul2dmy(jpon));
  printf("Azimut coucher : %s\n", rad2dms(azipon));  
endif
endfunction

