function [ra dec rho] = sun_je2equa(JD, verbose)
% sun_je2equa : Coordonnees equatoriales apparentes du Soleil
% Usage : [ra dec rho] = sun_je2equa(JD);
% Entree :
%    JD: date du calcul jours juliens ephemerides
% Sorties :
%    ra   : asc. droite vraie du Soleil
%    dec  : declinaison vraie du Soleil
%    rho  : distance Terre-Soleil
% Les angles sont en radians et les distances en UA.
if nargin < 2, verbose = false; endif
T = jul2juc(JD);
[LO_dg, nu_dg] = sun_longi_dg(T);
lamb = LO_dg*pi/180.;
excent = eccentricity(T);
rho = 1.000001018*(1-excent*excent)/(1+excent*cos(nu_dg*pi/180.));
[dpsi_dg deps_dg] = nutationEcli_dg(T, true);
lamb += dpsi_dg*pi/180;
[dLamb, dBeta] = aberrEcli(lamb, 0, lamb, excent, earth_longiPerih_dg(T)*pi/180.);
%dLamb = -pi*(20.4898/rho)/(3600*180);
lamb += dLamb;
% lamb : longitude ecliptique geometrique vraie du Soleil
[ra dec] = ecli2equa(lamb, 0 , (obliquity_dg(T) + deps_dg)*pi/180.);
if verbose
   printf("Informations sur le Soleil\n");
   printf("Distance                : %f UA\n", rho);
   printf("AD et DE apparentes     : %s, %s\n",...
             rad2hms(ra), rad2dms2(dec));  
endif             
endfunction