function [longSolV_dg, anomalieV_dg] = sun_longi_dg(T)
% sun_longi_dg : Longitude (en dg) du Soleil a la date T (courante par defaut)
% C'est la longitude geometrique du vrai soleil mesuree par rapport a
% l'equinoxe moyen de la date (precession prise en compte), et non a
% l'equinoxe vraie (nutation non prise en compte).
% Usage : [longSolV_dg, anomalieV_dg] = sun_longi_dg(T);
% Entree :
%	  siecle julien du calcul : T  = (JD-2451545)/36525;
% Sorties :
%	 longSolV_dg  : longitude vraie (geometrique) du Soleil a la date T
% !!!!!!!!!!! angles en degres !!!!!!!!

% Longitude géométrique "moyenne" du Soleil/gamma de la date
if nargin < 1
  ju = julNow(); je = ju + jul2deltaT(ju); T = jul2juc(je);
end

L_dg = 280.46646 + T*(36000.76983 + T*0.0003032);
L_dg = mod(L_dg, 360);
% Anomalie moyenne du Soleil/gamma de la date
M_dg = 357.52911 + T*(35999.05029 - T*0.0001537);
M_dg = mod(M_dg,360);
M = M_dg*pi/180;
% Equation du centre (C = M - v)
C_dg = (1.914602 - T*(0.004817 + T*0.000014*T))*sin(M) ...
     + (0.019993 - T*0.000101)*sin(2*M) ...
     + 0.000289*sin(3*M);
       
longSolV_dg =  L_dg + C_dg;
anomalieV_dg = M_dg + C_dg;
endfunction
