function [jlev, jtra, jcou] = sun_transit(ju, longiA, latiA)
global longiCou latiCou
h0 = -(0.8333)*pi/180; % rayon angulaire soleil + refraction
sinh0 = sin(h0);
jtra = -1; jlev = -1; jcou = -1;
%% Constantes ou données initiales
if nargin < 3, latiA = latiCou; endif
if nargin < 2, longiA = longiCou; endif
if nargin < 1, ju = julNow(); endif
omegaT = (360.98564736629/360.)*2*pi; % vrot_terre rd/jours
% Arret des itérations a 0.1 s près.
epstest = 0.1/86400; % 1/2 s en jour
% jour julien de la date d'observation UT à midi
jref = floor(ju + 0.5);
DeltaT = jul2deltaT(jref);
% Ascension droite méridien local à jref
Aref = jul2agst_rd(jref) + longiA;
% Postion du soleil à jref UT
[raSref dec rho] = sun_je2equa(jref + DeltaT);
deltaAsc = realmod2(raSref - Aref, 2*pi);
jtransit = jref + deltaAsc/omegaT;
cosH = (sinh0 - sin(latiA)*sin(dec))/(cos(latiA)*cos(dec));
if abs(cosH) > 1, return; endif % pas de solution
H = acos(cosH);
jlever = jref + (deltaAsc - H)/omegaT;
jcoucher = jref + (deltaAsc + H)/omegaT;
for i=1:10
  jtransit_old = jtransit; 
  jlever_old = jlever;  
  jcoucher_old = jcoucher;  
  [raSref dec rho] = sun_je2equa(jtransit + DeltaT);
  jtransit = jref + realmod2(raSref - Aref, 2*pi)/omegaT;
  % Postion du soleil le matin
  [raSlev dec rho] = sun_je2equa(jlever + DeltaT); 
  cosHlev = (sinh0 - sin(latiA)*sin(dec))/(cos(latiA)*cos(dec));
  jlever = jref + (realmod2(raSlev - Aref, 2*pi) - acos(cosHlev))/omegaT;
  % Postion du soleil le soir
  [raScou dec rho] = sun_je2equa(jcoucher + DeltaT);
  cosHcou = (sinh0 - sin(latiA)*sin(dec))/(cos(latiA)*cos(dec));  
  jcoucher = jref + (realmod2(raScou - Aref, 2*pi) + acos(cosHcou))/omegaT;
  if abs(jlever_old-jlever) < epstest && abs(jcoucher_old-jcoucher) < epstest ...
                                   && abs(jtransit_old-jtransit) < epstest
    break;
  endif
endfor
jtra = jtransit;
jlev = jlever;
jcou = jcoucher;
endfunction
