function JJ = ymdhms2jul(a, m, j, h, mn, s)
% ymdhms2jul : Conversion an,mois,jour,h,m,s en jours juliens
% Usage : JJ = ymdhms2jul(a, m, d, h, m, s)
% Entrees :
%   a = annee (attention 1 av. J.-C. est note 0, etc..)
%   m = mois (1 a 12)
%   j = jour decimal de 1.000 a 31.999 (10.5 c'est le 10 a midi)
%   h, mn, s = heure minute seconde du jour          
% Retour  : 
%   JJ = nombre de jours decimaux ecoules depuis le 1/1/-4712 a 12h
% Remarque : j termine par .5 quand JJ termine par .0 et reciproquement
if nargin < 6, s = 0; endif
if nargin < 5, mn = 0; endif
if nargin < 4, h = 12; endif
if nargin < 3, j = 1; endif
if nargin < 2, m = 1; endif
if nargin < 1, a = 2000; endif
j += (h + (mn+ s/60.)/60.)/24.;
% Changement origine des annees pour qu'elles soient > 0 afin que
% les troncatures soient toutes dans le meme sens
    A = a + 4800;
% Changement origine au 1er Mars, afin que la succession des jours
% soit toujours la meme
    M = m; 
	if M <= 2 
		A--; 
		M += 12;
	end
% Correction Julienne/gregorienne 
    if a < 1582 || (a == 1582 && m < 10) || (a == 1582 && m == 10 && j < 15)
		JJ = -38.;
    else
		JJ = floor(A/400) - floor(A/100);
	end
% Decompte avec troncature magique pour les 30/31 et correction des
% changements d'origine 
    JJ += j + floor(36525*A/100) + floor(306*(M+1)/10) - 32167.5;
endfunction